==> audiochain-1.1.5-src.tgz: org/audiochain/ui/gui/mixer/SynchronizationSettingsDialog.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui.mixer;

import static org.audiochain.ui.gui.CommonComponentFactory.*;
import static org.audiochain.ui.gui.Dialog.*;

import java.io.IOException;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.audiochain.ui.gui.GlobalGuiContext;
import org.audiochain.ui.gui.LightEmittingDiodeCheckBox;
import org.audiochain.ui.gui.NotificationDialog;
import org.audiochain.ui.sync.SyncManager;

import static org.audiochain.ui.sync.SyncManager.*;


public class SynchronizationSettingsDialog extends NotificationDialog {
	private JPanel mainPanel;
	private JLabel syncServerEnabledLabel;
	private JCheckBox syncServerEnabledCheckBox;
	private JLabel syncServerAtStartupEnabledLabel;
	private JCheckBox syncServerAtStartupEnabledCheckBox;
	private JLabel loggingEnabledLabel;
	private JCheckBox loggingEnabledCheckBox;
	private JLabel serverPortLabel;
	private JTextField serverPortField;
	private JLabel messageDisplayBehaviourLabel;
	private JComboBox messageDisplayBehaviourComboBox;
	
	public SynchronizationSettingsDialog(Object caller) {
		super(caller);
		init();
	}

	protected void init() {
		initComponents();
		initValues();
		registerListeners();
		createLayout();
		
		if (isButtonPressed(caller, "Synchronization Settings", mainPanel, applyButton)) {
			SyncManager syncManager = SyncManager.getInstance();
			syncManager.setLoggingEnabled(loggingEnabledCheckBox.isSelected());
			syncManager.setSyncServerAtStartupEnabled(syncServerAtStartupEnabledCheckBox.isSelected());
			syncManager.setServerPort(Integer.parseInt(serverPortField.getText().trim()));
			syncManager.setSyncServerEnabled(syncServerEnabledCheckBox.isSelected());
			syncManager.setSyncProcessDisplayBehaviour((SyncProcessDisplayBehaviour) messageDisplayBehaviourComboBox.getSelectedItem());
		}
	}

	private void initComponents() {
		mainPanel = new JPanel();
		mainPanel.setOpaque(false);
		applyButton = new JButton("Apply Changes");
		syncServerEnabledLabel = new JLabel("Sync Service Enabled:");
		syncServerEnabledCheckBox = new LightEmittingDiodeCheckBox();
		syncServerAtStartupEnabledLabel = new JLabel("Enable Sync Service On Startup:");
		syncServerAtStartupEnabledCheckBox = new LightEmittingDiodeCheckBox();
		serverPortLabel = new JLabel("Sync Service Port:");
		serverPortField = new JTextField(5);
		serverPortField.setName("Sync Service Port");
		loggingEnabledLabel = new JLabel("Logging Enabled:");
		loggingEnabledCheckBox = new LightEmittingDiodeCheckBox();
		messageDisplayBehaviourLabel = new JLabel("Sync Dialog Display Behaviour:");
		messageDisplayBehaviourComboBox = createComboBox((Object[]) SyncProcessDisplayBehaviour.values());
	}

	private void initValues() {
		SyncManager syncManager = SyncManager.getInstance();
		syncServerEnabledCheckBox.setSelected(syncManager.isSyncServerRunning());
		syncServerAtStartupEnabledCheckBox.setSelected(syncManager.isSyncServerAtStartupEnabled());
		loggingEnabledCheckBox.setSelected(syncManager.isLoggingEnabled());
		serverPortField.setText(String.valueOf(syncManager.getServerPort()));
	}

	private void registerListeners() {
		serverPortField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				checkServerPortValue();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				checkServerPortValue();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				checkServerPortValue();
			}

			private void checkServerPortValue() {
				putNotification(serverPortField, null);
				try {
					String text = serverPortField.getText();
					int port = Integer.parseInt(text.trim());
					SyncManager.getInstance().testServerPort(port);
				} catch (NumberFormatException e) {
					putNotification(serverPortField, serverPortLabel.getText() + " must be a numeric (integral) value.");
				} catch (IOException e) {
					putNotification(serverPortField, serverPortLabel.getText() + " cannot be bound: " + e.getMessage());
				} catch (IllegalArgumentException e) {
					putNotification(serverPortField, serverPortLabel.getText() + " is invalid. " + e.getMessage());
				}
			}
		});
	}
	
	private void createLayout() {
		GroupLayout layout = new GroupLayout(mainPanel);
		mainPanel.setLayout(layout);
		layout.setAutoCreateContainerGaps(true);
		layout.setAutoCreateGaps(true);
		
		layout.setHorizontalGroup(layout.createParallelGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(syncServerEnabledLabel)
					.addComponent(serverPortLabel)
					.addComponent(syncServerAtStartupEnabledLabel)
					.addComponent(loggingEnabledLabel)
					.addComponent(messageDisplayBehaviourLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(syncServerEnabledCheckBox)
					.addComponent(serverPortField)
					.addComponent(syncServerAtStartupEnabledCheckBox)
					.addComponent(loggingEnabledCheckBox)
					.addComponent(messageDisplayBehaviourComboBox)
				)
			)
		);
		
		layout.setVerticalGroup(layout.createSequentialGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(syncServerEnabledLabel)
					.addComponent(syncServerEnabledCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(serverPortLabel)
					.addComponent(serverPortField)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(syncServerAtStartupEnabledLabel)
				.addComponent(syncServerAtStartupEnabledCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(loggingEnabledLabel)
					.addComponent(loggingEnabledCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(messageDisplayBehaviourLabel)
					.addComponent(messageDisplayBehaviourComboBox)
			)
			// add additional gap to the dialog buttons, because the notification label causes an additional distance to the dialog title on the top
			.addGap(20)
		);
	}

	@SuppressWarnings("unused")
	public static void main(String[] args) {
		GlobalGuiContext.getGuiSettings().initializeUIManager();
		new SynchronizationSettingsDialog(new Object());
		System.exit(0);
	}
}

==> audiochain-1.1.6-src.tgz: org/audiochain/ui/gui/mixer/SynchronizationSettingsDialog.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui.mixer;

import static org.audiochain.ui.gui.CommonComponentFactory.createComboBox;
import static org.audiochain.ui.gui.Dialog.isButtonPressed;

import java.io.IOException;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.audiochain.ui.gui.GuiSettings;
import org.audiochain.ui.gui.LightEmittingDiodeCheckBox;
import org.audiochain.ui.gui.NotificationDialog;
import org.audiochain.ui.sync.SyncManager;
import org.audiochain.ui.sync.SyncManager.SyncProcessDisplayBehaviour;


public class SynchronizationSettingsDialog extends NotificationDialog {
	private JPanel mainPanel;
	private JLabel syncServerEnabledLabel;
	private JCheckBox syncServerEnabledCheckBox;
	private JLabel syncServerAtStartupEnabledLabel;
	private JCheckBox syncServerAtStartupEnabledCheckBox;
	private JLabel loggingEnabledLabel;
	private JCheckBox loggingEnabledCheckBox;
	private JLabel serverPortLabel;
	private JTextField serverPortField;
	private JLabel messageDisplayBehaviourLabel;
	private JComboBox<SyncProcessDisplayBehaviour> messageDisplayBehaviourComboBox;
	
	public SynchronizationSettingsDialog(Object caller) {
		super(caller);
		init();
	}

	protected void init() {
		initComponents();
		initValues();
		registerListeners();
		createLayout();
		
		if (isButtonPressed(caller, "Synchronization Settings", mainPanel, applyButton)) {
			SyncManager syncManager = SyncManager.getInstance();
			syncManager.setLoggingEnabled(loggingEnabledCheckBox.isSelected());
			syncManager.setSyncServerAtStartupEnabled(syncServerAtStartupEnabledCheckBox.isSelected());
			syncManager.setServerPort(Integer.parseInt(serverPortField.getText().trim()));
			syncManager.setSyncServerEnabled(syncServerEnabledCheckBox.isSelected());
			syncManager.setSyncProcessDisplayBehaviour((SyncProcessDisplayBehaviour) messageDisplayBehaviourComboBox.getSelectedItem());
		}
	}

	private void initComponents() {
		mainPanel = new JPanel();
		mainPanel.setOpaque(false);
		applyButton = new JButton("Apply Changes");
		syncServerEnabledLabel = new JLabel("Sync Service Enabled:");
		syncServerEnabledCheckBox = new LightEmittingDiodeCheckBox();
		syncServerAtStartupEnabledLabel = new JLabel("Enable Sync Service On Startup:");
		syncServerAtStartupEnabledCheckBox = new LightEmittingDiodeCheckBox();
		serverPortLabel = new JLabel("Sync Service Port:");
		serverPortField = new JTextField(5);
		serverPortField.setName("Sync Service Port");
		loggingEnabledLabel = new JLabel("Logging Enabled:");
		loggingEnabledCheckBox = new LightEmittingDiodeCheckBox();
		messageDisplayBehaviourLabel = new JLabel("Sync Dialog Display Behaviour:");
		messageDisplayBehaviourComboBox = createComboBox(SyncProcessDisplayBehaviour.values());
	}

	private void initValues() {
		SyncManager syncManager = SyncManager.getInstance();
		syncServerEnabledCheckBox.setSelected(syncManager.isSyncServerRunning());
		syncServerAtStartupEnabledCheckBox.setSelected(syncManager.isSyncServerAtStartupEnabled());
		loggingEnabledCheckBox.setSelected(syncManager.isLoggingEnabled());
		serverPortField.setText(String.valueOf(syncManager.getServerPort()));
	}

	private void registerListeners() {
		serverPortField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				checkServerPortValue();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				checkServerPortValue();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				checkServerPortValue();
			}

			private void checkServerPortValue() {
				putNotification(serverPortField, null);
				try {
					String text = serverPortField.getText();
					int port = Integer.parseInt(text.trim());
					SyncManager.getInstance().testServerPort(port);
				} catch (NumberFormatException e) {
					putNotification(serverPortField, serverPortLabel.getText() + " must be a numeric (integral) value.");
				} catch (IOException e) {
					putNotification(serverPortField, serverPortLabel.getText() + " cannot be bound: " + e.getMessage());
				} catch (IllegalArgumentException e) {
					putNotification(serverPortField, serverPortLabel.getText() + " is invalid. " + e.getMessage());
				}
			}
		});
	}
	
	private void createLayout() {
		GroupLayout layout = new GroupLayout(mainPanel);
		mainPanel.setLayout(layout);
		layout.setAutoCreateContainerGaps(true);
		layout.setAutoCreateGaps(true);
		
		layout.setHorizontalGroup(layout.createParallelGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(syncServerEnabledLabel)
					.addComponent(serverPortLabel)
					.addComponent(syncServerAtStartupEnabledLabel)
					.addComponent(loggingEnabledLabel)
					.addComponent(messageDisplayBehaviourLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(syncServerEnabledCheckBox)
					.addComponent(serverPortField)
					.addComponent(syncServerAtStartupEnabledCheckBox)
					.addComponent(loggingEnabledCheckBox)
					.addComponent(messageDisplayBehaviourComboBox)
				)
			)
		);
		
		layout.setVerticalGroup(layout.createSequentialGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(syncServerEnabledLabel)
					.addComponent(syncServerEnabledCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(serverPortLabel)
					.addComponent(serverPortField)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(syncServerAtStartupEnabledLabel)
				.addComponent(syncServerAtStartupEnabledCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(loggingEnabledLabel)
					.addComponent(loggingEnabledCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(messageDisplayBehaviourLabel)
					.addComponent(messageDisplayBehaviourComboBox)
			)
			// add additional gap to the dialog buttons, because the notification label causes an additional distance to the dialog title on the top
			.addGap(20)
		);
	}

	@SuppressWarnings("unused")
	public static void main(String[] args) {
		GuiSettings.getInstance().initializeUIManager();
		new SynchronizationSettingsDialog(new Object());
		System.exit(0);
	}
}
